darkhistory.electrons.elec_cooling — DarkHistory documentation

# darkhistory.electrons.elec_cooling

Function for calculating the electron cooling transfer function.

Functions

`get_elec_cooling_tf`(eleceng, photeng, rs, xHII) | Transfer functions for complete electron cooling through inverse Compton scattering (ICS) and atomic processes.

#### Previous topic

darkhistory.electrons

#### Next topic

darkhistory.electrons.elec_cooling.get_elec_cooling_tf

### This Page

Show Source